@@ -1,18 +1,13 @@
 import json
 import os
 import shutil
-import sys
+from io import StringIO
 from pathlib import Path
 
 from cwltool.main import main
 
 from .util import get_data, needs_docker
 
-if sys.version_info[0] < 3:
-    from StringIO import StringIO
-else:
-    from io import StringIO
-
 
 @needs_docker
 def test_for_910(tmp_path: Path) -> None:
